@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2005 Joseph L. Chuma, TRIUMF
+Copyright (C) 2010 Joseph L. Chuma
 
 This program is free software; you can redistribute it and/or
 modify it under the terms of the GNU General Public License
@@ -31,6 +31,8 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 BEGIN_EVENT_TABLE( VisualizationSpeedButtonPanel, wxPanel )
   EVT_BUTTON( ID_clearGraphicsPage, VisualizationSpeedButtonPanel::OnClearGraphicsPage )
   EVT_BUTTON( ID_drawGraph, VisualizationSpeedButtonPanel::OnDrawGraph )
+  EVT_BUTTON( ID_3dplot, VisualizationSpeedButtonPanel::On3DPlot )
+  EVT_BUTTON( ID_drawFigure, VisualizationSpeedButtonPanel::OnDrawFigure )
   EVT_BUTTON( ID_drawText, VisualizationSpeedButtonPanel::OnDrawText )
   EVT_BUTTON( ID_peakFind, VisualizationSpeedButtonPanel::OnPeakFind )
   EVT_BUTTON( ID_drawFigures, VisualizationSpeedButtonPanel::OnDrawFigures )
@@ -64,6 +66,12 @@ VisualizationSpeedButtonPanel::VisualizationSpeedButtonPanel( VisualizationWindo
   drawGraphButton->SetToolTip( wxT("draw a graph") );
   sizer->Add( drawGraphButton, wxSizerFlags(0).Border(wxTOP|wxRIGHT,5) );
 
+  wxBitmapButton *threeDPlotButton =
+    new wxBitmapButton( (wxWindow*)this, ID_3dplot,
+                        wxBitmap(imageDir+wxT("/3dplot.bmp"),wxBITMAP_TYPE_BMP) );
+  threeDPlotButton->SetToolTip( wxT("draw a 3D graph") );
+  sizer->Add( threeDPlotButton, wxSizerFlags(0).Border(wxTOP|wxRIGHT,5) );
+
   wxBitmapButton *drawTextButton =
     new wxBitmapButton( (wxWindow*)this, ID_drawText,
                         wxBitmap(imageDir+wxT("/drawtext.GIF"),wxBITMAP_TYPE_GIF) );
@@ -78,11 +86,11 @@ VisualizationSpeedButtonPanel::VisualizationSpeedButtonPanel( VisualizationWindo
   peakFindButton->SetToolTip( wxT("find peaks") );
   sizer->Add( peakFindButton, wxSizerFlags(0).Border(wxTOP|wxRIGHT,5) );
   
-  wxBitmapButton *drawFiguresButton =
-    new wxBitmapButton( (wxWindow*)this, ID_drawFigures,
+  wxBitmapButton *drawFigureButton =
+    new wxBitmapButton( (wxWindow*)this, ID_drawFigure,
                         wxBitmap(imageDir+wxT("/drawfigure.GIF"),wxBITMAP_TYPE_GIF) );
-  drawFiguresButton->SetToolTip( wxT("draw geometric figures") );
-  sizer->Add( drawFiguresButton, wxSizerFlags(0).Border(wxTOP|wxRIGHT,5) );
+  drawFigureButton->SetToolTip( wxT("draw geometric figures") );
+  sizer->Add( drawFigureButton, wxSizerFlags(0).Border(wxTOP|wxRIGHT,5) );
 
   sizer->InsertSpacer( 6, 10 );
   
@@ -261,6 +269,12 @@ void VisualizationSpeedButtonPanel::OnClearGraphicsPage( wxCommandEvent &event )
 void VisualizationSpeedButtonPanel::OnDrawGraph( wxCommandEvent &event )
 { visualizationWindow_->OnDrawGraph( event ); }
   
+void VisualizationSpeedButtonPanel::On3DPlot( wxCommandEvent &event )
+{ visualizationWindow_->On3DPlot( event ); }
+  
+void VisualizationSpeedButtonPanel::OnDrawFigure( wxCommandEvent &event )
+{ visualizationWindow_->OnDrawFigure( event ); }
+  
 void VisualizationSpeedButtonPanel::OnDrawText( wxCommandEvent &event )
 { visualizationWindow_->OnDrawText( event ); }
 
